==> huaweicloudsdkdws-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/list_alarm_detail_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAlarmDetailResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'alarm_details': 'list[AlarmDetailResponse]'
    }

    attribute_map = {
        'count': 'count',
        'alarm_details': 'alarm_details'
    }

    def __init__(self, count=None, alarm_details=None):
        r"""ListAlarmDetailResponse

        The model defined in huaweicloud sdk

        :param count: 告警详情总数
        :type count: int
        :param alarm_details: 告警列表
        :type alarm_details: list[:class:`huaweicloudsdkdws.v2.AlarmDetailResponse`]
        """
        
        super(ListAlarmDetailResponse, self).__init__()

        self._count = None
        self._alarm_details = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if alarm_details is not None:
            self.alarm_details = alarm_details

    @property
    def count(self):
        r"""Gets the count of this ListAlarmDetailResponse.

        告警详情总数

        :return: The count of this ListAlarmDetailResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ListAlarmDetailResponse.

        告警详情总数

        :param count: The count of this ListAlarmDetailResponse.
        :type count: int
        """
        self._count = count

    @property
    def alarm_details(self):
        r"""Gets the alarm_details of this ListAlarmDetailResponse.

        告警列表

        :return: The alarm_details of this ListAlarmDetailResponse.
        :rtype: list[:class:`huaweicloudsdkdws.v2.AlarmDetailResponse`]
        """
        return self._alarm_details

    @alarm_details.setter
    def alarm_details(self, alarm_details):
        r"""Sets the alarm_details of this ListAlarmDetailResponse.

        告警列表

        :param alarm_details: The alarm_details of this ListAlarmDetailResponse.
        :type alarm_details: list[:class:`huaweicloudsdkdws.v2.AlarmDetailResponse`]
        """
        self._alarm_details = alarm_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAlarmDetailResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdws-3.1.155-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/list_alarm_detail_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAlarmDetailResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'alarm_details': 'list[AlarmDetailResponse]'
    }

    attribute_map = {
        'count': 'count',
        'alarm_details': 'alarm_details'
    }

    def __init__(self, count=None, alarm_details=None):
        r"""ListAlarmDetailResponse

        The model defined in huaweicloud sdk

        :param count: **参数解释**： 告警详情总数。 **取值范围**： 不涉及。
        :type count: int
        :param alarm_details: **参数解释**： 告警列表。 **取值范围**： 不涉及。
        :type alarm_details: list[:class:`huaweicloudsdkdws.v2.AlarmDetailResponse`]
        """
        
        super(ListAlarmDetailResponse, self).__init__()

        self._count = None
        self._alarm_details = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if alarm_details is not None:
            self.alarm_details = alarm_details

    @property
    def count(self):
        r"""Gets the count of this ListAlarmDetailResponse.

        **参数解释**： 告警详情总数。 **取值范围**： 不涉及。

        :return: The count of this ListAlarmDetailResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ListAlarmDetailResponse.

        **参数解释**： 告警详情总数。 **取值范围**： 不涉及。

        :param count: The count of this ListAlarmDetailResponse.
        :type count: int
        """
        self._count = count

    @property
    def alarm_details(self):
        r"""Gets the alarm_details of this ListAlarmDetailResponse.

        **参数解释**： 告警列表。 **取值范围**： 不涉及。

        :return: The alarm_details of this ListAlarmDetailResponse.
        :rtype: list[:class:`huaweicloudsdkdws.v2.AlarmDetailResponse`]
        """
        return self._alarm_details

    @alarm_details.setter
    def alarm_details(self, alarm_details):
        r"""Sets the alarm_details of this ListAlarmDetailResponse.

        **参数解释**： 告警列表。 **取值范围**： 不涉及。

        :param alarm_details: The alarm_details of this ListAlarmDetailResponse.
        :type alarm_details: list[:class:`huaweicloudsdkdws.v2.AlarmDetailResponse`]
        """
        self._alarm_details = alarm_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAlarmDetailResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
